#%%global rc_ver 2
%global baserelease 3
%global polly_srcdir polly-%{version}%{?rc_ver:rc%{rc_ver}}.src
%global major 11
%global _vpath_builddir _build
%global __requires_exclude	devel\\(libPollyPPCG|devel\\(libPollyISL

%bcond_with cuda

Name:		polly
Version:	11.0.1
Release:	%mkrel %{baserelease}%{?rc_ver:.rc%{rc_ver}}
Summary:	LLVM Framework for High-Level Loop and Data-Locality Optimizations
Group:		Development/Other
License:	NCSA
URL:		http://polly.llvm.org
Source0: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{polly_srcdir}.tar.xz
Source1: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{polly_srcdir}.tar.xz.sig
Source2: tstellar-gpg-key.asc

# from FC
Patch0:		polly-subproject-extension.patch
# from SuSE
Patch1:		polly-10.0.0-pthread.patch

BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires:	cmake
BuildRequires:	pkgconfig(OpenCL)
BuildRequires:	llvm-devel = %{version}
BuildRequires:	llvm-test = %{version}
BuildRequires:	clang-devel = %{version}
BuildRequires:  ninja-build
BuildRequires:	python3-lit
BuildRequires:	python3-sphinx
%if %{with cuda}
BuildRequires:	nvidia-cuda-toolkit
%endif

# For origin certification
BuildRequires:	gnupg2
Requires:	clang
Requires:	clang

%description
Polly is a high-level loop and data-locality optimizer and optimization
infrastructure for LLVM. It uses an abstract mathematical representation based
on integer polyhedron to analyze and optimize the memory access pattern of a
program.

%package devel
Summary: Polly header files
Requires: %{name} = %{version}-%{release}
Conflicts: %name < 10.0.0-7

%description devel
Polly header files.

%package doc
Summary:	Documentation for Polly
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}

%description doc
Documentation for the Polly optimizer.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{polly_srcdir} -p1

%build

%cmake	-G Ninja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DLLVM_CONFIG_PATH=%{_bindir}/llvm-config \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DCMAKE_PREFIX_PATH=%{_libdir}/cmake/llvm/ \
\
	-DLLVM_ENABLE_SPHINX:BOOL=ON \
	-DSPHINX_WARNINGS_AS_ERRORS=OFF \
\
	-DPOLLY_BUNDLED_ISL:BOOL=ON \
	-DPOLLY_ENABLE_GPGPU_CODEGEN:BOOL=ON \
%if %{with cuda}
	-DCUDA_NVCC_EXECUTABLE:FILEPATH=%{_bindir}/nvcc
%endif
\
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64
%else
	-DLLVM_LIBDIR_SUFFIX=
%endif

%cmake_build
%cmake_build --target docs-polly-html
%cmake_build --target docs-polly-man

%install
mkdir -p %{buildroot}%{_mandir}/man1
%cmake_install

# manually install html docs & man pages
cp -pr %{_vpath_builddir}/docs/html ./
rm -f ./html/.buildinfo
rm -f ./html/objects.inv
install -m 644 %{_vpath_builddir}/docs/man/*.1 %{buildroot}%{_mandir}/man1/

# From https://polly.llvm.org/docs/UsingPollyWithClang.html
mkdir -p %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/pollycc <<EOF
#!/bin/sh
%{_bindir}/clang -O3 -Xclang -load -Xclang %{_libdir}/LLVMPolly.so "\$@"
EOF
cat > %{buildroot}%{_bindir}/pollyc++ <<EOF
#!/bin/sh
%{_bindir}/clang++ -O3 -Xclang -load -Xclang %{_libdir}/LLVMPolly.so "\$@"
EOF
chmod 755 %{buildroot}%{_bindir}/pollycc %{buildroot}%{_bindir}/pollyc++

%check
%cmake_build --target check-polly || :

%files
%license LICENSE.txt
%{_bindir}/*
%{_includedir}/*
%{_mandir}/man1/*
%{_libdir}/cmake/*
%{_libdir}/libPolly.so.%{major}
# these are libraries without .so versions, not devel
%{_libdir}/LLVMPolly.so
%ifarch %ix86 x86_64
%{_libdir}/libGPURuntime.so
%endif
%{_libdir}/libPollyISL.so
%{_libdir}/libPollyPPCG.so

%files devel
%{_libdir}/libPolly.so
%{_includedir}/polly
%{_libdir}/cmake/polly
 
%files doc
%doc html


%changelog
* Thu Jan 07 2021 tv <tv> 11.0.1-3.mga8
+ Revision: 1669447
- LLVM 11.0.1 final

* Tue Dec 22 2020 tv <tv> 11.0.1-2.rc2.mga8
+ Revision: 1662973
- llvm 11.0.1-rc2

* Fri Dec 04 2020 tv <tv> 11.0.1-1.rc1.mga8
+ Revision: 1652575
- llvm 11.0.1 RC1

* Fri Nov 27 2020 tv <tv> 11.0.0-1.mga8
+ Revision: 1649685
- libGPURuntime.so is there only on x86
- ignore testsuite results for now
- 11.0.0
- 11.0.0

* Thu Oct 08 2020 akien <akien> 10.0.1-1.mga8
+ Revision: 1632869
- Temporarily disable libGPURuntime on arm
- Version 10.0.1
+ ghibo <ghibo>
- Remove script to get git sources (obsolete)
- Add docs-polly-man to cmake target for building man pages.
- Add LLVMPolly.so, libGPURuntime.so, libPollyISL.so, libPollyPPCG.so to main package filelist.
- Reintroduce devel(libPollyPPCG|libPollyISL) requires_exception to allow polly-devel installation.
+ tv <tv>
- BR clang-devel
- gpgverify sources
- fix license
- better summary
- use new cmake macros
- no need for BR: llvm-static
- split devel pkg

* Fri Jun 12 2020 ghibo <ghibo> 10.0.0-6.mga8
+ Revision: 1592843
- merge ninja build targets

* Thu Jun 11 2020 ghibo <ghibo> 10.0.0-5.mga8
+ Revision: 1592619
- Fix docs

* Thu Jun 11 2020 ghibo <ghibo> 10.0.0-4.mga8
+ Revision: 1592591
- Add ninja-build to BuildRequires
- more fixing broken deps.
- cmake options cleanup.
- add cuda bcond.
- Add doc subpackage
- Add HTML docs
- Add man page
- Sync Patch0 from FC
- Add Patch1 from Suse for fixing pthread linking order.
- Fix broken deps about libPollyPPCG.
- Add llvm-test and python-sphinx to BuildRequires.
- Remove isl from BuildRequires and use newer bundled version.

* Tue Jun 09 2020 ghibo <ghibo> 10.0.0-3.mga8
+ Revision: 1591495
- Add OpenCL-devel and isl-devel to BuildRequires.

* Tue Jun 09 2020 ghibo <ghibo> 10.0.0-2.mga8
+ Revision: 1591451
- Bump release

* Tue Mar 24 2020 tv <tv> 10.0.0-1.mga8
+ Revision: 1559505
- 10.0.0 final

* Sun Mar 22 2020 tv <tv> 10.0.0-0.1.rc5.mga8
+ Revision: 1558889
- adjust filelist
- 10.0.0 rc5
- rebuild with llvm 10

* Sun Feb 16 2020 umeabot <umeabot> 9.0.0-3.mga8
+ Revision: 1533428
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sat Sep 21 2019 tv <tv> 9.0.0-2.mga8
+ Revision: 1444354
- 9.0.0 Release

* Tue Sep 17 2019 tv <tv> 9.0.0-1.mga8
+ Revision: 1443075
- 9.0.0rc3

* Sat Apr 13 2019 ghibo <ghibo> 8.0.0-1.mga7
+ Revision: 1389829
- Update to release 8.0.0.
- Build with llvm 8.0.0.

* Tue Mar 19 2019 ghibo <ghibo> 7.0.1-1.mga7
+ Revision: 1378899
- imported package polly

